All of lore.kernel.org
 help / color / mirror / Atom feed
* [Buildroot] [PATCH 1/4] support/testing: ddrescue: use dmsetup from lvm2
@ 2025-12-19 21:09 Julien Olivain via buildroot
  2025-12-19 21:09 ` [Buildroot] [PATCH 2/4] support/testing: ddrescue: bump test kernel to 6.18.2 Julien Olivain via buildroot
                   ` (4 more replies)
  0 siblings, 5 replies; 7+ messages in thread
From: Julien Olivain via buildroot @ 2025-12-19 21:09 UTC (permalink / raw)
  To: buildroot; +Cc: Julien Olivain

The ddresue runtime test is using the `dmsetup` command provided by the
dmraid package. This package is outdated and will be removed. This
command is also provided by the lvm2 package, which is still maintained.

This commit replaces the dmraid package by lvm2 in the test config.

Signed-off-by: Julien Olivain <ju.o@free.fr>
---
 support/testing/tests/package/test_ddrescue.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/support/testing/tests/package/test_ddrescue.py b/support/testing/tests/package/test_ddrescue.py
index 989abc8f01..042431eb7b 100644
--- a/support/testing/tests/package/test_ddrescue.py
+++ b/support/testing/tests/package/test_ddrescue.py
@@ -9,7 +9,7 @@ class TestDdrescue(infra.basetest.BRTest):
     # - A kernel config fragment enables loop blk dev and device
     #   mapper dm-dust, which are used to simulate a failing storage
     #   block device.
     # - dmraid user space package is needed to configure dm-dust
     config = \
         """
         BR2_aarch64=y
@@ -23,7 +23,7 @@ class TestDdrescue(infra.basetest.BRTest):
         BR2_LINUX_KERNEL_CONFIG_FRAGMENT_FILES="{}"
         BR2_LINUX_KERNEL_NEEDS_HOST_OPENSSL=y
         BR2_PACKAGE_DDRESCUE=y
-        BR2_PACKAGE_DMRAID=y
+        BR2_PACKAGE_LVM2=y
         BR2_TARGET_ROOTFS_CPIO=y
         BR2_TARGET_ROOTFS_CPIO_GZIP=y
         # BR2_TARGET_ROOTFS_TAR is not set
@@ -9,7 +9,7 @@ class TestDdrescue(infra.basetest.BRTest):
     #   mapper dm-dust, which are used to simulate a failing storage
     #   block device.
-    # - dmraid user space package is needed to configure dm-dust
+    # - lvm2 user space package is needed to configure dm-dust with dmsetup
     config = \
         """
-- 
2.52.0

_______________________________________________
buildroot mailing list
buildroot@buildroot.org
https://lists.buildroot.org/mailman/listinfo/buildroot

^ permalink raw reply related	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2026-01-07 17:49 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-12-19 21:09 [Buildroot] [PATCH 1/4] support/testing: ddrescue: use dmsetup from lvm2 Julien Olivain via buildroot
2025-12-19 21:09 ` [Buildroot] [PATCH 2/4] support/testing: ddrescue: bump test kernel to 6.18.2 Julien Olivain via buildroot
2025-12-19 21:09 ` [Buildroot] [PATCH 3/4] support/testing: ddrescue: use f-string for test config Julien Olivain via buildroot
2026-01-07 17:49   ` Arnout Vandecappelle via buildroot
2025-12-19 21:09 ` [Buildroot] [PATCH 4/4] package/ddrescue: bump version to 1.29.1 Julien Olivain via buildroot
2025-12-27 23:40 ` [Buildroot] [PATCH 1/4] support/testing: ddrescue: use dmsetup from lvm2 Thomas Petazzoni via buildroot
2026-01-07 17:49 ` Arnout Vandecappelle via buildroot

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.